@@ -9,92 +9,57 @@
 #'
 #'   A list of `query()` objects is expected.
 #'
-#' @param meddra_version MedDRA version
+#' @param meddra_version *Deprecated*, please use `version`
 #'
-#'   The MedDRA version used for coding the terms in the AE dataset should be
-#'   specified. If any of the queries is a SMQ or a customized query including a
-#'   SMQ, the parameter needs to be specified.
+#' @param whodd_version *Deprecated*, please use `version`
+#'
+#' @param version Dictionary version
+#'
+#'   The dictionary version used for coding the terms should be specified.
+#'   If any of the queries is a basket (SMQ, SDG, ....) or a customized query
+#'   including a basket, the parameter needs to be specified.
 #'
 #'   *Permitted Values*: A character string (the expected format is
 #'   company-specific)
 #'
-#' @param whodd_version WHO Drug Dictionary version
+#' @param get_smq_fun *Deprecated*, please use `get_terms_fun`
 #'
-#'   The version of the WHO Drug Dictionary used for coding the terms in the CM
-#'   dataset should be specified. If any of the queries is a SDG, the parameter
-#'   needs to be specified.
+#' @param get_sdg_fun *Deprecated*, please use `get_terms_fun`
 #'
-#'   *Permitted Values*: A character string (the expected format is
-#'   company-specific)
+#' @param get_terms_fun Function which returns the terms
 #'
-#' @param get_smq_fun Function which returns the terms of an SMQ
-#'
-#'   For each query specified for the `queries` parameter which refers to an SMQ
-#'   (i.e., those where the `definition` field is set to a `smq_select()` object
-#'   or a list which contains at least one `smq_select()` object) the specified
-#'   function is called to retrieve the terms defining the query. This function
-#'   is not provided by admiral as it is company specific, i.e., it has to be
-#'   implemented at company level.
-#'
-#'   The function must return a dataset with all the terms defining the SMQ. The
-#'   output dataset must contain the following variables.
-#'
-#'   - `TERM_LEVEL`: the variable to be used for defining a term of the SMQ, e.g.,
-#'   `AEDECOD`
-#'   - `TERM_NAME`: the name of the term if the variable `TERM_LEVEL` is
-#'   referring to is character
-#'   - `TERM_ID` the numeric id of the term if the variable `TERM_LEVEL` is
-#'   referring to is numeric
-#'   - `QUERY_NAME`: the name of the SMQ. The values must be the same for all
-#'   observations.
-#'
-#'   The function must provide the following parameters
-#'
-#'   - `smq_select`: A `smq_select()` object.
-#'   - `version`: The MedDRA version. The value specified for the
-#'   `meddra_version` in the `create_query_data()` call is passed to this
-#'   parameter.
-#'   - `keep_id`: If set to `TRUE`, the output dataset must contain the
-#'   `QUERY_ID` variable. The variable must be set to the numeric id of the SMQ.
-#'   - `temp_env`: A temporary environment is passed to this parameter. It can
-#'   be used to store data which is used for all SMQs in the
-#'   `create_query_data()` call. For example if the SMQs need to be read from a
-#'   database all SMQs can be read and stored in the environment when the first
-#'   SMQ is handled. For the other SMQs the terms can be retrieved from the
-#'   environment instead of accessing the database again.
-#'
-#' @param get_sdg_fun Function which returns the terms of an SDG
-#'
-#'   For each query specified for the `queries` parameter which refers to an SDG
-#'   the specified function is called to retrieve the terms defining the query.
+#'   For each query specified for the `queries` parameter referring to a basket
+#'   (i.e., those where the `definition` field is set to a `basket_select()`
+#'   object or a list which contains at least one `basket_select()` object) the
+#'   specified function is called to retrieve the terms defining the query.
 #'   This function is not provided by admiral as it is company specific, i.e.,
 #'   it has to be implemented at company level.
 #'
-#'   The function must return a dataset with all the terms defining the SDG. The
-#'   output dataset must contain the following variables.
+#'   The function must return a dataset with all the terms defining the basket.
+#'   The output dataset must contain the following variables.
 #'
-#'   - `TERM_LEVEL`: the variable to be used for defining a term of the SDG, e.g.,
-#'   `CMDECOD`
+#'   - `TERM_LEVEL`: the variable to be used for defining a term of the basket,
+#'    e.g., `AEDECOD`
 #'   - `TERM_NAME`: the name of the term if the variable `TERM_LEVEL` is
 #'   referring to is character
 #'   - `TERM_ID` the numeric id of the term if the variable `TERM_LEVEL` is
 #'   referring to is numeric
-#'   - `QUERY_NAME`: the name of the SDG. The values must be the same for all
-#'   observations.
+#'   - `QUERY_NAME`: the name of the basket. The values must be the same for
+#'   all observations.
 #'
 #'   The function must provide the following parameters
 #'
-#'   - `sdg_select`: A `sdg_select()` object.
-#'   - `version`: The WHO drug dictionary version. The value specified for the
-#'   `whodd_version` in the `create_query_data()` call is passed to this
+#'   - `basket_select`: A `basket_select()` object.
+#'   - `version`: The dictionary version. The value specified for the
+#'   `version` in the `create_query_data()` call is passed to this
 #'   parameter.
 #'   - `keep_id`: If set to `TRUE`, the output dataset must contain the
-#'   `QUERY_ID` variable. The variable must be set to the numeric id of the SDG.
+#'   `QUERY_ID` variable. The variable must be set to the numeric id of the basket.
 #'   - `temp_env`: A temporary environment is passed to this parameter. It can
-#'   be used to store data which is used for all SDGs in the
-#'   `create_query_data()` call. For example if the SDGs need to be read from a
-#'   database all SDGs can be read and stored in the environment when the first
-#'   SDG is handled. For the other SDGs the terms can be retrieved from the
+#'   be used to store data which is used for all baskets in the
+#'   `create_query_data()` call. For example if SMQs need to be read from a
+#'   database all SMQs can be read and stored in the environment when the first
+#'   SMQ is handled. For the other SMQs the terms can be retrieved from the
 #'   environment instead of accessing the database again.
 #'
 #' @details
@@ -104,14 +69,12 @@
 #'   to the `definition` field of the query: if the definition field of the
 #'   `query()` object is
 #'
-#'   * an `smq_select()` object, the terms are read from the SMQ
-#'   database by calling the function specified for the `get_smq_fun` parameter.
-#'   * an `sdg_select()` object, the terms are read from the SDG
-#'   database by calling the function specified for the `get_sdg_fun` parameter.
+#'   * a `basket_select()` object, the terms are read from the basket
+#'   database by calling the function specified for the `get_terms_fun` parameter.
 #'   * a data frame, the terms stored in the data frame are used.
-#'   * a list of data frames and `smq_select()` objects, all terms from
-#'   the data frames and all terms read from the SMQ database referenced by the
-#'   `smq_select()` objects are collated.
+#'   * a list of data frames and `basket_select()` objects, all terms from
+#'   the data frames and all terms read from the basket database referenced by the
+#'   `basket_select()` objects are collated.
 #'
 #' The following variables (as described in [Queries Dataset
 #' Documentation](../articles/queries_dataset.html)) are created:
@@ -123,34 +86,35 @@
 #'   element is not specified for a query, the variable is set to `NA`. If the
 #'   `id` element is not specified for any query, the variable is not created.
 #'   * `QUERY_SCOPE`: scope of the query as specified by the `scope` element of
-#'   the `smq_select()` object. For queries not defined by a `smq_select()`
+#'   the `basket_select()` object. For queries not defined by a `basket_select()`
 #'   object, the variable is set to `NA`. If none of the queries is defined by a
-#'   `smq_select()` object, the variable is not created.
+#'   `basket_select()` object, the variable is not created.
 #'   * `QUERY_SCOPE_NUM`: numeric scope of the query. It is set to `1` if the
-#'   scope is broad. Otherwise it is set to '2'. If the `add_scope_num` element
+#'   scope is broad. Otherwise it is set to `2`. If the `add_scope_num` element
 #'   equals `FALSE`, the variable is set to `NA`. If the `add_scope_num` element
-#'   equals `FALSE` for all SMQs or none of the queries is an SMQ , the variable
+#'   equals `FALSE` for all baskets or none of the queries is an basket , the variable
 #'   is not created.
 #'   * `TERM_LEVEL`: Name of the variable used to identify the terms.
 #'   * `TERM_NAME`: Value of the term variable if it is a character variable.
 #'   * `TERM_ID`: Value of the term variable if it is a numeric variable.
+#'   * `VERSION`: Set to the value of the `version` argument. If it is not
+#'   specified, the variable is not created.
 #'
-#' @author Stefan Bundfuss
+#' @author Stefan Bundfuss, Tamara Senior
 #'
 #' @return A dataset to be used as input dataset to the `dataset_queries`
 #'   argument in `derive_vars_query()`
 #'
-#' @family der_occds
-#' @keywords der_occds
+#' @family create_aux
+#' @keywords create_aux
 #'
-#' @seealso [derive_vars_query()], [query()], [smq_select()], [sdg_select()], [Queries Dataset
+#' @seealso [derive_vars_query()], [query()], [basket_select()], [Queries Dataset
 #' Documentation](../articles/queries_dataset.html)
 #'
 #' @export
 #'
 #' @examples
 #' library(tibble)
-#' library(magrittr, warn.conflicts = FALSE)
 #' library(dplyr, warn.conflicts = FALSE)
 #' library(admiral.test)
 #' library(admiral)
@@ -175,47 +139,51 @@
 #' pregsmq <- query(
 #'   prefix = "SMQ02",
 #'   id = auto,
-#'   definition = smq_select(
+#'   definition = basket_select(
 #'     name = "Pregnancy and neonatal topics (SMQ)",
-#'     scope = "NARROW"
+#'     scope = "NARROW",
+#'     type = "smq"
 #'   )
 #' )
 #'
 #' bilismq <- query(
 #'   prefix = "SMQ04",
-#'   definition = smq_select(
+#'   definition = basket_select(
 #'     id = 20000121L,
-#'     scope = "BROAD"
+#'     scope = "BROAD",
+#'     type = "smq"
 #'   )
 #' )
 #'
-#' # The get_smq_terms function from admiral.test is used for this example.
+#' # The get_terms function from admiral.test is used for this example.
 #' # In a real application a company-specific function must be used.
 #' create_query_data(
 #'   queries = list(pregsmq, bilismq),
-#'   get_smq_fun = admiral.test:::get_smq_terms,
-#'   meddra_version = "20.1"
+#'   get_terms_fun = admiral.test:::get_terms,
+#'   version = "20.1"
 #' )
 #'
 #' # create a query dataset for SDGs
 #' sdg <- query(
 #'   prefix = "SDG01",
 #'   id = auto,
-#'   definition = sdg_select(
-#'     name = "5-aminosalicylates for ulcerative colitis"
+#'   definition = basket_select(
+#'     name = "5-aminosalicylates for ulcerative colitis",
+#'     scope = NA_character_,
+#'     type = "sdg"
 #'   )
 #' )
 #'
-#' # The get_sdg_terms function from admiral.test is used for this example.
+#' # The get_terms function from admiral.test is used for this example.
 #' # In a real application a company-specific function must be used.
 #' create_query_data(
 #'   queries = list(sdg),
-#'   get_sdg_fun = admiral.test:::get_sdg_terms,
-#'   whodd_version = "2019-09"
+#'   get_terms_fun = admiral.test:::get_terms,
+#'   version = "2019-09"
 #' )
 #'
 #' # creating a query dataset for a customized query including SMQs
-#' # The get_smq_terms function from admiral.test is used for this example.
+#' # The get_terms function from admiral.test is used for this example.
 #' # In a real application a company-specific function must be used.
 #' create_query_data(
 #'   queries = list(
@@ -223,31 +191,53 @@
 #'       prefix = "CQ03",
 #'       name = "Special issues of interest",
 #'       definition = list(
-#'         smq_select(
+#'         basket_select(
 #'           name = "Pregnancy and neonatal topics (SMQ)",
-#'           scope = "NARROW"
+#'           scope = "NARROW",
+#'           type = "smq"
 #'         ),
 #'         cqterms
 #'       )
 #'     )
 #'   ),
-#'   get_smq_fun = admiral.test:::get_smq_terms,
-#'   meddra_version = "20.1"
+#'   get_terms_fun = admiral.test:::get_terms,
+#'   version = "20.1"
 #' )
 create_query_data <- function(queries,
-                              meddra_version = NULL,
-                              whodd_version = NULL,
-                              get_smq_fun = NULL,
-                              get_sdg_fun = NULL) {
+                              meddra_version = deprecated(),
+                              whodd_version = deprecated(),
+                              version = NULL,
+                              get_smq_fun = deprecated(),
+                              get_sdg_fun = deprecated(),
+                              get_terms_fun = NULL) {
+  if (!missing(meddra_version)) {
+    deprecate_stop(
+      "0.9.0",
+      "create_query_data(meddra_version = )", "create_query_data(version = )"
+    )
+  }
+  if (!missing(whodd_version)) {
+    deprecate_stop(
+      "0.9.0",
+      "create_query_data(whodd_version = )", "create_query_data(version = )"
+    )
+  }
+  if (!missing(get_smq_fun)) {
+    deprecate_stop(
+      "0.9.0",
+      "create_query_data(get_smq_fun = )", "create_query_data(get_terms_fun = )"
+    )
+  }
+  if (!missing(get_sdg_fun)) {
+    deprecate_stop(
+      "0.9.0",
+      "create_query_data(get_sdg_fun = )", "create_query_data(get_terms_fun = )"
+    )
+  }
   # check parameters
-  assert_character_scalar(meddra_version, optional = TRUE)
-  assert_character_scalar(whodd_version, optional = TRUE)
-  assert_function(get_smq_fun,
-    params = c("smq_select", "version", "keep_id", "temp_env"),
-    optional = TRUE
-  )
-  assert_function(get_sdg_fun,
-    params = c("sdg_select", "version", "keep_id", "temp_env"),
+  assert_character_scalar(version, optional = TRUE)
+  assert_function(get_terms_fun,
+    params = c("basket_select", "version", "keep_id", "temp_env"),
     optional = TRUE
   )
 
@@ -258,18 +248,17 @@ create_query_data <- function(queries,
   query_data <- vector("list", length(queries))
   for (i in seq_along(queries)) {
     # get term names and term variable
-    if (inherits(queries[[i]]$definition, "smq_select")) {
-      # query is a SMQ
+    if (inherits(queries[[i]]$definition, "basket_select")) {
+      # query is a basket
       query_data[[i]] <- get_terms_from_db(
-        version = meddra_version,
-        fun = get_smq_fun,
+        version = version,
+        fun = get_terms_fun,
         queries = queries,
         definition = queries[[i]]$definition,
         expect_query_name = TRUE,
         expect_query_id = !is.null(queries[[i]]$id),
         i = i,
-        temp_env = temp_env,
-        type = "SMQ"
+        temp_env = temp_env
       )
       query_data[[i]] <- mutate(query_data[[i]],
         QUERY_SCOPE = queries[[i]]$definition$scope
@@ -280,24 +269,11 @@ create_query_data <- function(queries,
             QUERY_SCOPE_NUM = if_else(QUERY_SCOPE == "BROAD", 1, 2)
           )
       }
-    } else if (inherits(queries[[i]]$definition, "sdg_select")) {
-      # query is a SDG
-      query_data[[i]] <- get_terms_from_db(
-        version = whodd_version,
-        fun = get_sdg_fun,
-        queries = queries,
-        definition = queries[[i]]$definition,
-        expect_query_name = TRUE,
-        expect_query_id = !is.null(queries[[i]]$id),
-        i = i,
-        temp_env = temp_env,
-        type = "SDG"
-      )
     } else if (is.data.frame(queries[[i]]$definition)) {
       # query is a customized query
       query_data[[i]] <- queries[[i]]$definition
     } else if (is.list(queries[[i]]$definition)) {
-      # query is defined by customized queries and SMQs
+      # query is defined by customized queries and baskets
       definition <- queries[[i]]$definition
       terms <- vector("list", length(definition))
       for (j in seq_along(definition)) {
@@ -305,13 +281,12 @@ create_query_data <- function(queries,
           terms[[j]] <- definition[[j]]
         } else {
           terms[[j]] <- get_terms_from_db(
-            version = meddra_version,
-            fun = get_smq_fun,
+            version = version,
+            fun = get_terms_fun,
             queries = queries,
             definition = definition[[j]],
             i = i,
-            temp_env = temp_env,
-            type = "SMQ"
+            temp_env = temp_env
           )
         }
       }
@@ -319,12 +294,14 @@ create_query_data <- function(queries,
     }
 
     # add mandatory variables
-    query_data[[i]] <- mutate(query_data[[i]],
+    query_data[[i]] <- mutate(
+      query_data[[i]],
       VAR_PREFIX = queries[[i]]$prefix
     )
 
     if (!is_auto(queries[[i]]$name)) {
-      query_data[[i]] <- mutate(query_data[[i]],
+      query_data[[i]] <- mutate(
+        query_data[[i]],
         QUERY_NAME = queries[[i]]$name
       )
     }
@@ -336,7 +313,15 @@ create_query_data <- function(queries,
       )
     }
   }
-  bind_rows(query_data)
+  queries <- bind_rows(query_data)
+
+  if (!is.null(version)) {
+    queries <- mutate(
+      queries,
+      VERSION = version
+    )
+  }
+  queries
 }
 
 #' Get Terms from the Queries Database
@@ -378,10 +363,6 @@ create_query_data <- function(queries,
 #'
 #'   The value is passed to the access function.
 #'
-#' @param type Type of query
-#'
-#'   *Permitted Values*: `"smq"`, `"sdg"`
-#'
 #' @family der_occds
 #' @keywords der_occds
 #'
@@ -395,35 +376,35 @@ get_terms_from_db <- function(version,
                               expect_query_name = FALSE,
                               expect_query_id = FALSE,
                               i,
-                              temp_env,
-                              type) {
+                              temp_env) {
   assert_db_requirements(
     version = version,
     version_arg_name = arg_name(substitute(version)),
     fun = fun,
     fun_arg_name = arg_name(substitute(fun)),
     queries = queries,
-    i = i,
-    type = type
+    i = i
   )
-  select <- rlang::parse_expr(paste0(str_to_lower(type), "_select = definition"))
   fun_call <- quo(fun(
-    !!select,
+    basket_select = definition,
     version = version,
     keep_id = expect_query_id,
     temp_env = temp_env
   ))
-  terms <- call_user_fun(fun_call)
+  terms <- call_user_fun(
+    fun(
+      basket_select = definition,
+      version = version,
+      keep_id = expect_query_id,
+      temp_env = temp_env
+    )
+  )
   assert_terms(
     terms,
     expect_query_name = expect_query_name,
     expect_query_id = expect_query_id,
     source_text = paste0(
-      "object returned by calling get_",
-      str_to_lower(type),
-      "_fun(",
-      str_to_lower(type),
-      "_select = ",
+      "object returned by calling get_terms_fun(basket_select = ",
       format(definition),
       ", version = ",
       dquote(version),
@@ -435,9 +416,9 @@ get_terms_from_db <- function(version,
   terms
 }
 
-#' Check required parameters for SMQ/SDG
+#' Check required parameters for a basket
 #'
-#' If SMQs or SDGs are requested, the version and a function to access the
+#' If a basket (SMQ, SDG, ....) are requested, the version and a function to access the
 #' database must be provided. The function checks these requirements.
 #'
 #' @param version Version provided by user
@@ -452,25 +433,20 @@ get_terms_from_db <- function(version,
 #'
 #' @param i Index of query being checked
 #'
-#' @param type Type of query
-#'
-#' Should be `"SMQ`" or `"SDG"`.
-#'
 #' @keywords source_specifications
 #' @family source_specifications
 #'
 #' @return An error is issued if `version` or `fun` is null.
 #'
 #' @author Stefan Bundfuss
-assert_db_requirements <- function(version, version_arg_name, fun, fun_arg_name, queries, i, type) {
+assert_db_requirements <- function(version, version_arg_name, fun, fun_arg_name, queries, i) {
   if (is.null(fun)) {
     msg <-
       paste0(
         fun_arg_name,
-        " is not specified. This is expected for ",
-        type,
+        " is not specified. This is expected for basket",
         "s.\n",
-        "A ", type, " is requested by query ",
+        "A basket is requested by query ",
         i,
         ":\n",
         paste(capture.output(str(queries[[i]])),
@@ -483,12 +459,9 @@ assert_db_requirements <- function(version, version_arg_name, fun, fun_arg_name,
     msg <-
       paste0(
         version_arg_name,
-        " is not specified. This is expected for ",
-        type,
+        " is not specified. This is expected for basket",
         "s.\n",
-        "A ",
-        type,
-        " is requested by query ",
+        "A basket is requested by query ",
         i,
         ":\n",
         paste(capture.output(str(queries[[i]])),
@@ -514,7 +487,7 @@ assert_db_requirements <- function(version, version_arg_name, fun, fun_arg_name,
 #'
 #'   *Permitted Values*: A character scalar or the `auto` keyword. The `auto`
 #'   keyword is permitted only for queries which are defined by an
-#'   `smq_select()` or `sdg_select()` object.
+#'   `basket_select()` object.
 #'
 #' @param id The value is used to populate `QUERY_ID` in the output dataset of
 #'   `create_query_data()`. If the `auto` keyword is specified, the variable is
@@ -522,12 +495,12 @@ assert_db_requirements <- function(version, version_arg_name, fun, fun_arg_name,
 #'
 #'   *Permitted Values*: A integer scalar or the `auto` keyword. The `auto`
 #'   keyword is permitted only for queries which are defined by an
-#'   `smq_select()` or `sdg_select()` object.
+#'   `basket_select()` object.
 #'
 #' @param add_scope_num Determines if  `QUERY_SCOPE_NUM` in the output dataset
 #'   of `create_query_data()` is populated
 #'
-#'   If the parameter is set to `TRUE`, the definition must be an `smq_select()`
+#'   If the parameter is set to `TRUE`, the definition must be an `basket_select()`
 #'   object.
 #'
 #'   *Default*: `FALSE`
@@ -536,12 +509,9 @@ assert_db_requirements <- function(version, version_arg_name, fun, fun_arg_name,
 #'
 #' @param definition Definition of terms belonging to the query
 #'
-#'   There are four different ways to define the terms:
+#'   There are three different ways to define the terms:
 #'
-#'   * An `smq_select()` object is specified to select a query from the SMQ
-#'     database.
-#'
-#'   * An `sdg_select()` object is specified to select a query from the SDG
+#'   * An `basket_select()` object is specified to select a query from the SMQ
 #'     database.
 #'
 #'   * A data frame with columns `TERM_LEVEL` and `TERM_NAME` or `TERM_ID` can
@@ -557,16 +527,16 @@ assert_db_requirements <- function(version, version_arg_name, fun, fun_arg_name,
 #'     or only numeric variables are used, `TERM_ID` or `TERM_NAME` respectively
 #'     can be omitted.
 #'
-#'   * A list of data frames and `smq_select()` objects can be specified to
+#'   * A list of data frames and `basket_select()` objects can be specified to
 #'   define a customized query based on custom terms and SMQs. The data frames
 #'   must have the same structure as described for the previous item.
 #'
-#'   *Permitted Values*: an `smq_select()` object, an `sdg_select()` object, a
-#'   data frame, or a list of data frames and `smq_select()` objects.
+#'   *Permitted Values*: an `basket_select()` object, a
+#'   data frame, or a list of data frames and `basket_select()` objects.
 #'
 #' @author Stefan Bundfuss
 #'
-#' @seealso [create_query_data()], [smq_select()], [sdg_select()], [Queries Dataset
+#' @seealso [create_query_data()], [basket_select()], [Queries Dataset
 #' Documentation](../articles/queries_dataset.html)
 #'
 #' @family source_specifications
@@ -580,15 +550,16 @@ assert_db_requirements <- function(version, version_arg_name, fun, fun_arg_name,
 #'
 #' # create a query for an SMQ
 #' library(tibble)
-#' library(magrittr, warn.conflicts = FALSE)
 #' library(dplyr, warn.conflicts = FALSE)
 #'
+#' # create a query for a SMQ
 #' query(
 #'   prefix = "SMQ02",
 #'   id = auto,
-#'   definition = smq_select(
+#'   definition = basket_select(
 #'     name = "Pregnancy and neonatal topics (SMQ)",
-#'     scope = "NARROW"
+#'     scope = "NARROW",
+#'     type = "smq"
 #'   )
 #' )
 #'
@@ -596,8 +567,10 @@ assert_db_requirements <- function(version, version_arg_name, fun, fun_arg_name,
 #' query(
 #'   prefix = "SDG01",
 #'   id = auto,
-#'   definition = sdg_select(
-#'     name = "5-aminosalicylates for ulcerative colitis"
+#'   definition = basket_select(
+#'     name = "5-aminosalicylates for ulcerative colitis",
+#'     scope = NA_character_,
+#'     type = "sdg"
 #'   )
 #' )
 #'
@@ -621,13 +594,15 @@ assert_db_requirements <- function(version, version_arg_name, fun, fun_arg_name,
 #'   name = "Special issues of interest",
 #'   definition = list(
 #'     cqterms,
-#'     smq_select(
+#'     basket_select(
 #'       name = "Pregnancy and neonatal topics (SMQ)",
-#'       scope = "NARROW"
+#'       scope = "NARROW",
+#'       type = "smq"
 #'     ),
-#'     smq_select(
+#'     basket_select(
 #'       id = 8050L,
-#'       scope = "BROAD"
+#'       scope = "BROAD",
+#'       type = "smq"
 #'     )
 #'   )
 #' )
@@ -652,7 +627,7 @@ query <- function(prefix,
   if (!is_auto(out$id)) {
     out$id <- eval_tidy(out$id)
   }
-  class(out) <- c("query", "list")
+  class(out) <- c("query", "source", "list")
   validate_query(out)
 }
 
@@ -660,7 +635,7 @@ query <- function(prefix,
 #'
 #' @param obj An object to be validated.
 #'
-#' @author Stefan Bundfuss
+#' @author Stefan Bundfuss Tamara Senior
 #'
 #' @keywords source_specifications
 #' @family source_specifications
@@ -688,7 +663,7 @@ validate_query <- function(obj) {
 
   scope <- values$scope
   assert_character_scalar(scope,
-    values = c("BROAD", "NARROW"),
+    values = c("BROAD", "NARROW", NA_character_),
     optional = TRUE
   )
 
@@ -696,19 +671,14 @@ validate_query <- function(obj) {
   assert_logical_scalar(add_scope_num,
     optional = TRUE
   )
-  if (add_scope_num && !inherits(values$definition, "smq_select")) {
-    abort("`add_scope_num == TRUE` must be used for SMQs only.")
-  }
 
-  if (inherits(values$definition, "smq_select")) {
-    validate_smq_select(values$definition)
-  } else if (inherits(values$definition, "sdg_select")) {
-    validate_sdg_select(values$definition)
+  if (inherits(values$definition, "basket_select")) {
+    validate_basket_select(values$definition)
   } else if (is.data.frame(values$definition) || is.list(values$definition)) {
     if (is_auto(values$name)) {
       abort(
         paste0(
-          "The auto keyword can be used for SMQs and SDGs only.\n",
+          "The auto keyword can be used for baskets only.\n",
           "It was provided for the name element."
         )
       )
@@ -716,7 +686,7 @@ validate_query <- function(obj) {
     if (is_auto(values$id)) {
       abort(
         paste0(
-          "The auto keyword can be used for SMQs and SDGs only.\n",
+          "The auto keyword can be used for baskets only.\n",
           "It was provided for the id element."
         )
       )
@@ -729,19 +699,20 @@ validate_query <- function(obj) {
     } else {
       is_valid <-
         map_lgl(values$definition, is.data.frame) |
-          map_lgl(values$definition, inherits, "smq_select")
+          map_lgl(values$definition, inherits, "basket_select")
       if (!all(is_valid)) {
-        info_msg <- paste(sprintf(
-          "\u2716 Element %s is %s",
-          which(!is_valid),
-          map_chr(values$definition[!is_valid], what_is_it)
-        ),
-        collapse = "\n"
+        info_msg <- paste(
+          sprintf(
+            "\u2716 Element %s is %s",
+            which(!is_valid),
+            map_chr(values$definition[!is_valid], what_is_it)
+          ),
+          collapse = "\n"
         )
         err_msg <- sprintf(
           paste(
             "Each element of the list in the definition field must be a data frame",
-            "or an object of class `smq_select` but the following are not:\n%s"
+            "or an object of class `basket_select` but the following are not:\n%s"
           ),
           info_msg
         )
@@ -760,8 +731,8 @@ validate_query <- function(obj) {
   } else {
     abort(
       paste0(
-        "`definition` expects a `smq_select` or `sdg_select` object, a data frame,",
-        " or a list of data frames and `smq_select` objects.\n",
+        "`definition` expects a `basket_select` object, a data frame,",
+        " or a list of data frames and `basket_select` objects\n",
         "An object of the following class was provided: ",
         class(values$definition)
       )
@@ -862,7 +833,7 @@ assert_terms <- function(terms,
       )
     }
   }
-  if (!"TERM_NAME" %in% vars & !"TERM_ID" %in% vars) {
+  if (!"TERM_NAME" %in% vars && !"TERM_ID" %in% vars) {
     abort(
       paste0(
         "Variable `TERM_NAME` or `TERM_ID` is required.\n",
@@ -876,8 +847,131 @@ assert_terms <- function(terms,
   }
 }
 
+#' Create a `basket_select` object
+#'
+#' @param name Name of the query used to select the definition of the query from
+#'   the company database.
+#'
+#' @param id Identifier of the query used to select the definition of the query
+#'   from the company database.
+#'
+#' @param scope Scope of the query used to select the definition of the query
+#'   from the company database.
+#'
+#'   *Permitted Values*: `"BROAD"`, `"NARROW"`, `NA_character_`
+#'
+#' @param type The type argument expects a character scalar. It is passed to the
+#' company specific get_terms() function such that the function can determine
+#' which sort of basket is requested
+#'
+#' @details Exactly one of `name` or `id` must be specified.
+#'
+#' @return An object of class `basket_select`.
+#'
+#' @author Tamara Senior
+#'
+#' @seealso [create_query_data()], [query()]
+#'
+#' @family source_specifications
+#' @keywords source_specifications
+#'
+#' @export
+basket_select <- function(name = NULL,
+                          id = NULL,
+                          scope = NULL,
+                          type) {
+  out <- list(
+    name = name,
+    id = id,
+    scope = scope,
+    type = type
+  )
+  class(out) <- c("basket_select", "source", "list")
+  validate_basket_select(out)
+}
+
+#' Validate an object is indeed a `basket_select` object
+#'
+#' @param obj An object to be validated.
+#'
+#' @seealso [basket_select()]
+#'
+#' @keywords source_specifications
+#' @family source_specifications
+#'
+#' @author Tamara Senior
+#'
+#' @export
+#'
+#' @return The original object.
+validate_basket_select <- function(obj) {
+  assert_s3_class(obj, "basket_select")
+  values <- unclass(obj)
+  name <- values$name
+  assert_character_scalar(name,
+    optional = TRUE
+  )
+  id <- values$id
+  assert_integer_scalar(id,
+    optional = TRUE
+  )
+  scope <- values$scope
+  assert_character_scalar(scope,
+    values = c("BROAD", "NARROW", NA_character_)
+  )
+
+  if (is.null(values$id) && is.null(values$name)) {
+    abort("Either id or name has to be non null.")
+  }
+  if (!is.null(values$id) && !is.null(values$name)) {
+    abort("Either id or name has to be null.")
+  }
+  obj
+}
+
+#' Returns a Character Representation of a `basket_select()` Object
+#'
+#' The function returns a character representation of a `basket_select()` object.
+#' It can be used for error messages for example.
+#'
+#' @param x A `basket_select()` object
+#'
+#' @param ... Not used
+#'
+#' @return A character representation of the `basket_select()` object
+#'
+#' @author Tamara Senior
+#'
+#' @seealso [basket_select()]
+#'
+#' @keywords source_specifications
+#' @family source_specifications
+#'
+#' @export
+#'
+#' @examples
+#'
+#' format(basket_select(id = 42, scope = "NARROW", type = "smq"))
+format.basket_select <- function(x, ...) {
+  paste0(
+    "basket_select(name = ",
+    dquote(x$name),
+    ", id = ",
+    format(x$id),
+    ", scope = ",
+    dquote(x$scope),
+    ", type = ",
+    dquote(x$type),
+    ")"
+  )
+}
+
 #' Create an `smq_select` object
 #'
+#' `r lifecycle::badge("deprecated")`
+#'
+#' This function is *deprecated*, please use `basket_select()` instead.
+#'
 #' @param name Name of the query used to select the definition of the query from
 #'   the company database.
 #'
@@ -904,91 +998,15 @@ assert_terms <- function(terms,
 smq_select <- function(name = NULL,
                        id = NULL,
                        scope = NULL) {
-  out <- list(
-    name = name,
-    id = id,
-    scope = scope
-  )
-  class(out) <- c("smq_select", "list")
-  validate_smq_select(out)
-}
-
-#' Validate an object is indeed a `smq_select` object
-#'
-#' @param obj An object to be validated.
-#'
-#' @seealso [smq_select()]
-#'
-#' @keywords source_specifications
-#' @family source_specifications
-#'
-#' @author Stefan Bundfuss
-#'
-#' @export
-#'
-#' @return The original object.
-validate_smq_select <- function(obj) {
-  assert_s3_class(obj, "smq_select")
-  values <- unclass(obj)
-  name <- values$name
-  assert_character_scalar(name,
-    optional = TRUE
-  )
-  id <- values$id
-  assert_integer_scalar(id,
-    optional = TRUE
-  )
-  scope <- values$scope
-  assert_character_scalar(scope,
-    values = c("BROAD", "NARROW")
-  )
-
-  if (is.null(values$id) && is.null(values$name)) {
-    abort("Either id or name has to be non null.")
-  }
-  if (!is.null(values$id) && !is.null(values$name)) {
-    abort("Either id or name has to be null.")
-  }
-  obj
-}
-
-#' Returns a Character Representation of a `smq_select()` Object
-#'
-#' The function returns a character representation of a `smq_select()` object.
-#' It can be used for error messages for example.
-#'
-#' @param x A `smq_select()` object
-#'
-#' @param ... Not used
-#'
-#' @return A character representation of the `smq_select()` object
-#'
-#' @author Stefan Bundfuss
-#'
-#' @seealso [smq_select()]
-#'
-#' @keywords source_specifications
-#' @family source_specifications
-#'
-#' @export
-#'
-#' @examples
-#'
-#' format(smq_select(id = 42, scope = "NARROW"))
-format.smq_select <- function(x, ...) {
-  paste0(
-    "smq_select(name = ",
-    dquote(x$name),
-    ", id = ",
-    format(x$id),
-    ", scope = ",
-    dquote(x$scope),
-    ")"
-  )
+  deprecate_stop("0.9.0", "smq_select()", "basket_select()")
 }
 
 #' Create an `sdg_select` object
 #'
+#' `r lifecycle::badge("deprecated")`
+#'
+#' This function is *deprecated*, please use `basket_select()` instead.
+#'
 #' @param name Name of the query used to select the definition of the query
 #'   from the company database.
 #'
@@ -1009,81 +1027,5 @@ format.smq_select <- function(x, ...) {
 #' @export
 sdg_select <- function(name = NULL,
                        id = NULL) {
-  out <- list(
-    name = name,
-    id = id
-  )
-  class(out) <- c("sdg_select", "list")
-  validate_sdg_select(out)
-}
-
-#' Validate an object is indeed a `sdg_select` object
-#'
-#' @param obj An object to be validated.
-#'
-#' @author Stefan Bundfuss
-#'
-#' @seealso [sdg_select()]
-#'
-#' @keywords source_specifications
-#' @family source_specifications
-#'
-#' @export
-#'
-#' @return The original object.
-validate_sdg_select <- function(obj) {
-  assert_s3_class(obj, "sdg_select")
-  values <- unclass(obj)
-  name <- values$name
-  assert_character_scalar(name,
-    optional = TRUE
-  )
-  id <- values$id
-  assert_integer_scalar(id,
-    optional = TRUE
-  )
-  if (is.null(values$id) && is.null(values$name)) {
-    abort("Either id or name has to be non null.")
-  }
-  if (!is.null(values$id) && !is.null(values$name)) {
-    abort("Either id or name has to be null.")
-  }
-  obj
-}
-
-#' Returns a Character Representation of a `sdg_select()` Object
-#'
-#' The function returns a character representation of a `sdg_select()` object.
-#' It can be used for error messages for example.
-#'
-#' @param x A `sdg_select()` object
-#'
-#' @param ... Not used
-#'
-#' @return A character representation of the `sdg_select()` object
-#'
-#' @author Stefan Bundfuss
-#'
-#' @seealso [sdg_select()]
-#'
-#' @keywords source_specifications
-#' @family source_specifications
-#'
-#' @export
-#'
-#' @examples
-#'
-#' format(
-#'   sdg_select(
-#'     name = "5-aminosalicylates for ulcerative colitis"
-#'   )
-#' )
-format.sdg_select <- function(x, ...) {
-  paste0(
-    "sdg_select(name = ",
-    dquote(x$name),
-    ", id = ",
-    format(x$id),
-    ")"
-  )
+  deprecate_stop("0.9.0", "sdg_select()", "basket_select()")
 }
