@@ -15,11 +15,14 @@
 #'
 #' @param meta_criteria Metadata data set holding the criteria (normally a case statement)
 #'
-#'   Default: `atoxgr_criteria_ctcv4`
+#' Permitted Values: atoxgr_criteria_ctcv4, atoxgr_criteria_ctcv5
 #'
 #'   {admiral} metadata data set `atoxgr_criteria_ctcv4` implements
 #'   [Common Terminology Criteria for Adverse Events (CTCAE)
 #'    v4.0](https://ctep.cancer.gov/protocoldevelopment/electronic_applications/ctc.htm)
+#'   {admiral} metadata data set `atoxgr_criteria_ctcv5` implements
+#'   [Common Terminology Criteria for Adverse Events (CTCAE)
+#'    v5.0](https://ctep.cancer.gov/protocoldevelopment/electronic_applications/ctc.htm)
 #'
 #'   The metadata should have the following variables:
 #'
@@ -67,9 +70,9 @@
 #' @export
 #'
 #' @examples
-#' library(dplyr, warn.conflicts = FALSE)
+#' library(tibble)
 #'
-#' data <- tibble::tribble(
+#' data <- tribble(
 #'   ~ATOXDSCL,                     ~AVAL,  ~ANRLO,   ~ANRHI, ~PARAM,
 #'   "Hypoglycemia",                119,    4,        7,      "Glucose (mmol/L)",
 #'   "Hypoglycemia",                120,    4,        7,      "Glucose (mmol/L)",
@@ -87,7 +90,7 @@
 #'   get_unit_expr = extract_unit(PARAM)
 #' )
 #'
-#' data <- tibble::tribble(
+#' data <- tribble(
 #'   ~ATOXDSCH,                     ~AVAL,  ~ANRLO,   ~ANRHI, ~PARAM,
 #'   "Hyperglycemia",               119,    4,        7,      "Glucose (mmol/L)",
 #'   "Hyperglycemia",               120,    4,        7,      "Glucose  (mmol/L)",
@@ -107,7 +110,7 @@
 derive_var_atoxgr_dir <- function(dataset,
                                   new_var,
                                   tox_description_var,
-                                  meta_criteria = atoxgr_criteria_ctcv4,
+                                  meta_criteria,
                                   criteria_direction,
                                   get_unit_expr) {
   new_var <- assert_symbol(enquo(new_var))
@@ -165,7 +168,6 @@ derive_var_atoxgr_dir <- function(dataset,
 
   # for each TERM apply criteria and create grade derivation
   for (i in seq_along(list_of_terms$TERM)) {
-
     # filter metadata on a term
     meta_this_term <- atoxgr_dir %>%
       filter(TERM_UPPER == list_of_terms$TERM_UPPER[i])
@@ -245,9 +247,9 @@ derive_var_atoxgr_dir <- function(dataset,
 #' @export
 #'
 #' @examples
-#' library(dplyr, warn.conflicts = FALSE)
+#' library(tibble)
 #'
-#' adlb <- tibble::tribble(
+#' adlb <- tribble(
 #'   ~ATOXDSCL,          ~ATOXDSCH,        ~ATOXGRL,      ~ATOXGRH,
 #'   "Hypoglycemia",     "Hyperglycemia",  NA_character_, "0",
 #'   "Hypoglycemia",     "Hyperglycemia",  "0",           "1",
