@@ -8,7 +8,7 @@ library(admiraldev)
 
 ## ----message=FALSE------------------------------------------------------------
 library(admiral)
-library(dplyr)
+library(dplyr, warn.conflicts = FALSE)
 library(admiral.test)
 library(lubridate)
 library(stringr)
@@ -262,7 +262,6 @@ advs <- advs %>%
     ATPTN = VSTPTNUM
   )
 
-
 count(advs, VISITNUM, VISIT, AVISITN, AVISIT)
 
 count(advs, VSTPTNUM, VSTPT, ATPTN, ATPT)
