@@ -133,6 +133,8 @@ advs <- advs %>%
 
 
 ## Get visit info ----
+# See also the "Visit and Period Variables" vignette
+# (https://pharmaverse.github.io/admiral/articles/visits_periods.html#visits)
 advs <- advs %>%
   # Derive Timing
   mutate(
@@ -240,6 +242,8 @@ advs <- advs %>%
   )
 
 ## Get treatment information ----
+# See also the "Visit and Period Variables" vignette
+# (https://pharmaverse.github.io/admiral/articles/visits_periods.html#treatment_bds)
 advs <- advs %>%
   # Assign TRTA, TRTP
   # Create End of Treatment Record
@@ -296,4 +300,4 @@ advs <- advs %>%
 # Save output ----
 
 dir <- tempdir() # Change to whichever directory you want to save the dataset in
-save(advs, file = file.path(dir, "advs.rda"), compress = "bzip2")
+saveRDS(advs, file = file.path(dir, "advs.rds"), compress = "bzip2")
