@@ -1,9 +1,7 @@
-library(admiral.test)
-data(admiral_ae)
-data(admiral_vs)
-
-test_that("call_derivation works", {
-  input <- admiral_vs[sample(seq_len(nrow(admiral_vs)), 1000), ]
+## Test 1: Test that call_derivation generates expected summary  ----
+# ---- call_derivation Test 1:  Test that call_derivation generates expected summary ----
+test_that("call_derivation Test 1:  Test that call_derivation generates expected summary", {
+  input <- admiral.test::admiral_vs[sample(seq_len(nrow(admiral.test::admiral_vs)), 1000), ]
 
   expected_output <- input %>%
     derive_summary_records(
@@ -57,8 +55,10 @@ test_that("call_derivation works", {
   )
 })
 
-test_that("call_derivation works", {
-  input <- admiral_ae[sample(seq_len(nrow(admiral_ae)), 1000), ] %>%
+## Test 2: Test that call_derivation generates expected imputation  ----
+# ---- call_derivation Test 2: Test that call_derivation generates expected imputation ----
+test_that("call_derivation Test 2: Test that call_derivation generates expected imputation", {
+  input <- admiral.test::admiral_ae[sample(seq_len(nrow(admiral.test::admiral_ae)), 1000), ] %>%
     left_join(admiral_adsl, by = "USUBJID")
 
   expected_output <- input %>%
@@ -91,9 +91,10 @@ test_that("call_derivation works", {
   expect_dfs_equal(expected_output, actual_output, keys = c("USUBJID", "AESEQ"))
 })
 
-
-test_that("call_derivation - Error is thrown if ... has no arguments", {
-  input <- admiral_ae[sample(seq_len(nrow(admiral_ae)), 1000), ] %>%
+## Test 3: Test that Error is thrown if ... has no arguments  ----
+# ---- call_derivation Test 3: Test that Error is thrown if ... has no arguments ----
+test_that("call_derivation Test 3: Test that Error is thrown if ... has no arguments", {
+  input <- admiral.test::admiral_ae[sample(seq_len(nrow(admiral.test::admiral_ae)), 1000), ] %>%
     left_join(admiral_adsl, by = "USUBJID")
 
   expect_error(
@@ -108,8 +109,10 @@ test_that("call_derivation - Error is thrown if ... has no arguments", {
   )
 })
 
-test_that("call_derivation - Error is thrown if ... arguments are not properly named", {
-  input <- admiral_ae[sample(seq_len(nrow(admiral_ae)), 1000), ] %>%
+## Test 4: Error is thrown if ... arguments are not properly named ----
+# ---- call_derivation Test 4: Error is thrown if ... arguments are not properly named ----
+test_that("call_derivation Test 4: Error is thrown if ... arguments are not properly named", {
+  input <- admiral.test::admiral_ae[sample(seq_len(nrow(admiral.test::admiral_ae)), 1000), ] %>%
     left_join(admiral_adsl, by = "USUBJID")
 
   expect_error(
@@ -126,8 +129,10 @@ test_that("call_derivation - Error is thrown if ... arguments are not properly n
   )
 })
 
-test_that("call_derivation - Error is thrown params is empty", {
-  input <- admiral_ae[sample(seq_len(nrow(admiral_ae)), 1000), ] %>%
+## Test 5: Error is thrown params is empty ----
+# ---- call_derivation Test 5: Error is thrown params is empty ----
+test_that("call_derivation Test 5: Error is thrown params is empty", {
+  input <- admiral.test::admiral_ae[sample(seq_len(nrow(admiral.test::admiral_ae)), 1000), ] %>%
     left_join(admiral_adsl, by = "USUBJID")
 
   expect_error(
@@ -144,8 +149,10 @@ test_that("call_derivation - Error is thrown params is empty", {
   )
 })
 
-test_that("call_derivation - Error is thrown if passed params are not proprely named", {
-  input <- admiral_ae[sample(seq_len(nrow(admiral_ae)), 1000), ] %>%
+## Test 6: Error is thrown if passed params are not properly named ----
+# ---- call_derivation Test 6: Error is thrown if passed params are not properly named ----
+test_that("call_derivation Test 6: Error is thrown if passed params are not properly named", {
+  input <- admiral.test::admiral_ae[sample(seq_len(nrow(admiral.test::admiral_ae)), 1000), ] %>%
     left_join(admiral_adsl, by = "USUBJID")
 
   expect_error(
@@ -163,8 +170,10 @@ test_that("call_derivation - Error is thrown if passed params are not proprely n
   )
 })
 
-test_that("call_derivation - Error is thrown if `...` arguments are not properly named", {
-  input <- admiral_ae[sample(seq_len(nrow(admiral_ae)), 1000), ] %>%
+## Test 7: Error is thrown if `...` arguments are not properly named ----
+# ---- call_derivation Test 7: Error is thrown if `...` arguments are not properly named ----
+test_that("call_derivation Test 7: Error is thrown if `...` arguments are not properly named", {
+  input <- admiral.test::admiral_ae[sample(seq_len(nrow(admiral.test::admiral_ae)), 1000), ] %>%
     left_join(admiral_adsl, by = "USUBJID")
 
   expect_error(
@@ -180,3 +189,13 @@ test_that("call_derivation - Error is thrown if `...` arguments are not properly
     )
   )
 })
+
+## Test 8: Error is thrown if duplicate parameters ----
+# ---- call_derivation Test 8: Error is thrown if duplicate parameters ----
+test_that("call_derivation Test 8: Error is thrown if duplicate parameters", {
+  expect_error(
+    params(dtc = VSDTC, dtc = VSDTC, new_vars_prefix = "A"),
+    "The following parameters have been specified more than once: `dtc`",
+    fixed = TRUE
+  )
+})
