@@ -34,7 +34,6 @@ vs <- tibble::tribble(
   "ST42-2", "HEIGHT", "Height", 58, 2
 ) %>% mutate(STUDYID = "ST42")
 
-
 # derive_vars_merged ----
 ## Test 1: merge all variables ----
 test_that("derive_vars_merged Test 1: merge all variables", {
@@ -93,11 +92,12 @@ test_that("derive_vars_merged Test 3: merge last value and flag matched by group
 
 ## Test 4: error if variable in both datasets ----
 test_that("derive_vars_merged Test 4: error if variable in both datasets", {
-  expect_error(derive_vars_merged(advs,
-    dataset_add = adsl,
-    by_vars = vars(USUBJID)
-  ),
-  regexp = ""
+  expect_error(
+    derive_vars_merged(advs,
+      dataset_add = adsl,
+      by_vars = vars(USUBJID)
+    ),
+    regexp = ""
   )
 })
 
@@ -170,7 +170,7 @@ test_that("derive_vars_merged_dtm Test 6: merge first date", {
 
 # derive_var_merged_cat ----
 ## Test 7: merge categorized variable ----
-test_that("derive_vars_merged_cat Test 7: merge categorized variable", {
+test_that("derive_var_merged_cat Test 7: merge categorized variable", {
   get_region <- function(x) {
     if_else(x %in% c("AUT", "NOR"), "EUROPE", "AFRICA")
   }
@@ -197,7 +197,7 @@ test_that("derive_vars_merged_cat Test 7: merge categorized variable", {
 })
 
 ## Test 8: define value for non-matched by groups ----
-test_that("derive_vars_merged_cat Test 8: define value for non-matched by groups", {
+test_that("derive_var_merged_cat Test 8: define value for non-matched by groups", {
   get_vscat <- function(x) {
     if_else(x == "BASELINE", "BASELINE", "POST-BASELINE")
   }
@@ -228,7 +228,7 @@ test_that("derive_vars_merged_cat Test 8: define value for non-matched by groups
 
 # derive_var_merged_exist_flag ----
 ## Test 9: merge existence flag ----
-test_that("derive_vars_merged_exist_flag Test 9: merge existence flag", {
+test_that("derive_var_merged_exist_flag Test 9: merge existence flag", {
   actual <- derive_var_merged_exist_flag(
     adsl,
     dataset_add = advs,
@@ -249,8 +249,8 @@ test_that("derive_vars_merged_exist_flag Test 9: merge existence flag", {
 })
 
 # derive_var_merged_character ----
-## Test 10: merge character variable, no transformation ----
-test_that("derive_var_merged_character Test 10: merge character variable, no transformation", {
+## Test 10: no transformation ----
+test_that("derive_var_merged_character Test 10: no transformation", {
   actual <- derive_var_merged_character(
     adsl,
     dataset_add = advs,
@@ -272,8 +272,8 @@ test_that("derive_var_merged_character Test 10: merge character variable, no tra
   )
 })
 
-## Test 11: merge character variable, upper case ----
-test_that("derive_var_merged_character Test 11: merge character variable, upper case", {
+## Test 11: upper case ----
+test_that("derive_var_merged_character Test 11: upper case", {
   actual <- derive_var_merged_character(
     adsl,
     dataset_add = advs,
@@ -297,8 +297,8 @@ test_that("derive_var_merged_character Test 11: merge character variable, upper
   )
 })
 
-## Test 12: merge character variable, lower case ----
-test_that("derive_var_merged_character Test 12: merge character variable, lower case", {
+## Test 12: lower case ----
+test_that("derive_var_merged_character Test 12: lower case", {
   actual <- derive_var_merged_character(
     adsl,
     dataset_add = advs,
@@ -321,8 +321,8 @@ test_that("derive_var_merged_character Test 12: merge character variable, lower
   )
 })
 
-## Test 13: merge character variable, title case ----
-test_that("derive_var_merged_character Test 13: merge character variable, title case", {
+## Test 13: title case ----
+test_that("derive_var_merged_character Test 13: title case", {
   actual <- derive_var_merged_character(
     adsl,
     dataset_add = advs,
@@ -345,9 +345,8 @@ test_that("derive_var_merged_character Test 13: merge character variable, title
   )
 })
 
-
-
-## Test 14: merge lookup table
+# derive_vars_merged_lookup ----
+## Test 14: merge lookup table ----
 test_that("derive_vars_merged_lookup Test 14: merge lookup table", {
   param_lookup <- tibble::tribble(
     ~VSTESTCD, ~VSTEST, ~PARAMCD, ~DESCRIPTION,
@@ -379,3 +378,141 @@ test_that("derive_vars_merged_lookup Test 14: merge lookup table", {
     keys = c("USUBJID", "VSSEQ", "VSTESTCD")
   )
 })
+
+
+
+## the lookup table
+## Test 15:  all by_vars have records in the lookup table ----
+test_that("derive_vars_merged_lookup Test 15:  all by_vars have records in the lookup table", {
+  param_lookup <- tibble::tribble(
+    ~VSTESTCD, ~VSTEST, ~PARAMCD, ~DESCRIPTION,
+    "WEIGHT", "Weight", "WEIGHT", "Weight (kg)",
+    "HEIGHT", "Height", "HEIGHT", "Height (cm)",
+    "BMI", "Body Mass Index", "BMI", "Body Mass Index(kg/m^2)",
+    "DIABP", "Diastolic Blood Pressure", "DIABP", "Diastolic Blood Pressure (mmHg)"
+  )
+
+  attr(param_lookup$VSTESTCD, "label") <- "Vital Signs Test Short Name"
+  attr(param_lookup$VSTEST, "label") <- "Vital Signs Test Name"
+
+
+  actual <- derive_vars_merged_lookup(
+    vs,
+    dataset_add = param_lookup,
+    by_vars = vars(VSTESTCD, VSTEST),
+    new_var = vars(PARAMCD, PARAM = DESCRIPTION),
+    print_not_mapped = TRUE
+  )
+
+  expected <-
+    left_join(vs, param_lookup, by = c("VSTESTCD", "VSTEST")) %>%
+    rename(PARAM = DESCRIPTION)
+
+
+  expect_dfs_equal(
+    base = expected,
+    compare = actual,
+    keys = c("USUBJID", "VSSEQ", "VSTESTCD")
+  )
+})
+
+# get_not_mapped ----
+## Test 16: not all by_vars have records in the lookup table ----
+test_that("get_not_mapped Test 16: not all by_vars have records in the lookup table", {
+  param_lookup <- tibble::tribble(
+    ~VSTESTCD, ~VSTEST, ~PARAMCD, ~DESCRIPTION,
+    "WEIGHT", "Weight", "WEIGHT", "Weight (kg)",
+    "HEIGHT", "Height", "HEIGHT", "Height (cm)",
+    "BMI", "Body Mass Index", "BMI", "Body Mass Index(kg/m^2)"
+  )
+
+  attr(param_lookup$VSTESTCD, "label") <- "Vital Signs Test Short Name"
+  attr(param_lookup$VSTEST, "label") <- "Vital Signs Test Name"
+
+
+  act_vs_param <- derive_vars_merged_lookup(
+    vs,
+    dataset_add = param_lookup,
+    by_vars = vars(VSTESTCD, VSTEST),
+    new_var = vars(PARAMCD, PARAM = DESCRIPTION),
+    print_not_mapped = TRUE
+  )
+
+  actual <- get_not_mapped()
+
+  expected <- left_join(vs, param_lookup, by = c("VSTESTCD", "VSTEST")) %>%
+    rename(PARAM = DESCRIPTION) %>%
+    filter(is.na(PARAMCD)) %>%
+    select(VSTESTCD, VSTEST) %>%
+    distinct()
+
+  expect_dfs_equal(
+    base = expected,
+    compare = actual,
+    keys = c("VSTESTCD", "VSTEST")
+  )
+})
+
+# derive_var_merged_summary ----
+## Test 17: dataset == dataset_add, no filter ----
+test_that("derive_var_merged_summary Test 17: dataset == dataset_add, no filter", {
+  expected <- tibble::tribble(
+    ~AVISIT,  ~ASEQ, ~AVAL, ~MEANVIS,
+    "WEEK 1",     1,    10,       10,
+    "WEEK 1",     2,    NA,       10,
+    "WEEK 2",     3,    NA,       NA,
+    "WEEK 3",     4,    42,       42,
+    "WEEK 4",     5,    12,       13,
+    "WEEK 4",     6,    12,       13,
+    "WEEK 4",     7,    15,       13
+  )
+
+  adbds <- select(expected, -MEANVIS)
+
+  expect_dfs_equal(
+    base = expected,
+    compare = derive_var_merged_summary(
+      adbds,
+      dataset_add = adbds,
+      by_vars = vars(AVISIT),
+      new_var = MEANVIS,
+      analysis_var = AVAL,
+      summary_fun = function(x) mean(x, na.rm = TRUE)
+    ),
+    keys = c("AVISIT", "ASEQ")
+  )
+})
+
+## Test 18: dataset != dataset_add, filter ----
+test_that("derive_var_merged_summary Test 18: dataset != dataset_add, filter", {
+  expected <- tibble::tribble(
+    ~USUBJID, ~MEANPBL,
+    "1",          13.5,
+    "2",            NA,
+    "3",          42.0
+  )
+
+  adbds <- tibble::tribble(
+    ~USUBJID, ~ADY, ~AVAL,
+    "1",        -3,    10,
+    "1",         2,    12,
+    "1",         8,    15,
+    "3",         4,    42
+  )
+
+  adsl <- select(expected, -MEANPBL)
+
+  expect_dfs_equal(
+    base = expected,
+    compare = derive_var_merged_summary(
+      adsl,
+      dataset_add = adbds,
+      by_vars = vars(USUBJID),
+      new_var = MEANPBL,
+      filter_add = ADY > 0,
+      analysis_var = AVAL,
+      summary_fun = function(x) mean(x, na.rm = TRUE)
+    ),
+    keys = c("USUBJID")
+  )
+})
