@@ -1,10 +1,7 @@
-library(tibble)
-library(lubridate)
-
 # derive_param_tte ----
 ## Test 1: new observations with analysis date are derived correctly ----
 test_that("derive_param_tte Test 1: new observations with analysis date are derived correctly", {
-  adsl <- tribble(
+  adsl <- tibble::tribble(
     ~USUBJID, ~DTHFL, ~DTHDT,            ~LSTALVDT,         ~TRTSDT,           ~TRTSDTF,
     "03",     "Y",    ymd("2021-08-21"), ymd("2021-08-21"), ymd("2021-08-10"), NA,
     "04",     "N",    NA,                ymd("2021-05-24"), ymd("2021-02-03"), NA
@@ -33,10 +30,10 @@ test_that("derive_param_tte Test 1: new observations with analysis date are deri
     )
   )
 
-  expected_output <- tribble(
+  expected_output <- tibble::tribble(
     ~USUBJID, ~ADT,              ~CNSR, ~EVENTDESC,              ~SRCDOM, ~SRCVAR,
-    "03",     ymd("2021-08-21"), 0L,    "DEATH",                 "ADSL",  "DTHDT",
-    "04",     ymd("2021-05-24"), 1L,    "LAST KNOWN ALIVE DATE", "ADSL",  "LSTALVDT"
+    "03",     ymd("2021-08-21"),    0L, "DEATH",                 "ADSL",  "DTHDT",
+    "04",     ymd("2021-05-24"),    1L, "LAST KNOWN ALIVE DATE", "ADSL",  "LSTALVDT"
   ) %>%
     mutate(
       STUDYID = "AB42",
@@ -78,13 +75,13 @@ test_that("derive_param_tte Test 2: new parameter with analysis datetime is deri
 
   adrs <- tibble::tribble(
     ~USUBJID, ~AVALC, ~ADTM,                          ~ASEQ,
-    "01",     "SD",   ymd_hms("2021-01-03 10:56:00"), 1,
-    "01",     "PR",   ymd_hms("2021-03-04 11:13:00"), 2,
-    "01",     "PD",   ymd_hms("2021-05-05 12:02:00"), 3,
-    "02",     "PD",   ymd_hms("2021-02-03 10:56:00"), 1,
-    "04",     "SD",   ymd_hms("2021-02-13 10:56:00"), 1,
-    "04",     "PR",   ymd_hms("2021-04-14 11:13:00"), 2,
-    "04",     "CR",   ymd_hms("2021-05-15 12:02:00"), 3
+    "01",     "SD",   ymd_hms("2021-01-03 10:56:00"),     1,
+    "01",     "PR",   ymd_hms("2021-03-04 11:13:00"),     2,
+    "01",     "PD",   ymd_hms("2021-05-05 12:02:00"),     3,
+    "02",     "PD",   ymd_hms("2021-02-03 10:56:00"),     1,
+    "04",     "SD",   ymd_hms("2021-02-13 10:56:00"),     1,
+    "04",     "PR",   ymd_hms("2021-04-14 11:13:00"),     2,
+    "04",     "CR",   ymd_hms("2021-05-15 12:02:00"),     3
   ) %>%
     mutate(STUDYID = "AB42", PARAMCD = "OVR")
 
@@ -134,13 +131,13 @@ test_that("derive_param_tte Test 2: new parameter with analysis datetime is deri
   )
 
   # nolint start
-  expected_output <- tribble(
+  expected_output <- tibble::tribble(
     ~USUBJID, ~ADTM,                          ~CNSR, ~EVENTDESC,              ~SRCDOM, ~SRCVAR,   ~SRCSEQ,
-    "01",     ymd_hms("2021-05-05 12:02:00"), 0L,    "PD",                    "ADRS",  "ADTM",    3,
-    "02",     ymd_hms("2021-02-03 10:56:00"), 0L,    "PD",                    "ADRS",  "ADTM",    1,
-    "03",     as_datetime(ymd("2021-08-21")), 0L,    "DEATH",                 "ADSL",  "DTHDT",   NA,
-    "04",     ymd_hms("2021-05-15 12:02:00"), 1L,    "LAST TUMOR ASSESSMENT", "ADRS",  "ADTM",    NA,
-    "05",     ymd_hms("2021-04-05 11:22:33"), 1L,    "TREATMENT START",       "ADSL",  "TRTSDTM", NA
+    "01",     ymd_hms("2021-05-05 12:02:00"),    0L, "PD",                    "ADRS",  "ADTM",          3,
+    "02",     ymd_hms("2021-02-03 10:56:00"),    0L, "PD",                    "ADRS",  "ADTM",          1,
+    "03",     as_datetime(ymd("2021-08-21")),    0L, "DEATH",                 "ADSL",  "DTHDT",        NA,
+    "04",     ymd_hms("2021-05-15 12:02:00"),    1L, "LAST TUMOR ASSESSMENT", "ADRS",  "ADTM",         NA,
+    "05",     ymd_hms("2021-04-05 11:22:33"),    1L, "TREATMENT START",       "ADSL",  "TRTSDTM",      NA
   ) %>%
     # nolint end
     mutate(
@@ -184,9 +181,9 @@ test_that("derive_param_tte Test 3: error is issued if DTC variables specified f
 
   ae <- tibble::tribble(
     ~USUBJID, ~AESTDTC,           ~AESEQ,
-    "01",     "2021-01-03T10:56", 1,
-    "01",     "2021-03-04",       2,
-    "01",     "2021",             3
+    "01",     "2021-01-03T10:56",      1,
+    "01",     "2021-03-04",            2,
+    "01",     "2021",                  3
   ) %>%
     mutate(STUDYID = "AB42")
 
@@ -239,9 +236,9 @@ test_that("derive_param_tte Test 4: by_vars parameter works correctly", {
 
   ae <- tibble::tribble(
     ~USUBJID, ~AESTDTC,     ~AESEQ, ~AEDECOD,
-    "01",     "2021-01-03", 1,      "Flu",
-    "01",     "2021-03-04", 2,      "Cough",
-    "01",     "2021-01-01", 3,      "Flu"
+    "01",     "2021-01-03",      1, "Flu",
+    "01",     "2021-03-04",      2, "Cough",
+    "01",     "2021-01-01",      3, "Flu"
   ) %>%
     mutate(
       STUDYID = "AB42",
@@ -273,10 +270,10 @@ test_that("derive_param_tte Test 4: by_vars parameter works correctly", {
   # nolint start
   expected_output <- tibble::tribble(
     ~USUBJID, ~ADT,              ~CNSR, ~EVENTDESC,     ~SRCDOM, ~SRCVAR,   ~SRCSEQ, ~PARCAT2, ~PARAMCD,
-    "01",     ymd("2021-01-01"), 0L,    "AE",           "AE",    "AESTDTC", 3,       "Flu",    "TTAE2",
-    "02",     ymd("2021-02-03"), 1L,    "END OF STUDY", "ADSL",  "EOSDT",   NA,      "Flu",    "TTAE2",
-    "01",     ymd("2021-03-04"), 0L,    "AE",           "AE",    "AESTDTC", 2,       "Cough",  "TTAE1",
-    "02",     ymd("2021-02-03"), 1L,    "END OF STUDY", "ADSL",  "EOSDT",   NA,      "Cough",  "TTAE1"
+    "01",     ymd("2021-01-01"),    0L, "AE",           "AE",    "AESTDTC",       3, "Flu",    "TTAE2",
+    "02",     ymd("2021-02-03"),    1L, "END OF STUDY", "ADSL",  "EOSDT",        NA, "Flu",    "TTAE2",
+    "01",     ymd("2021-03-04"),    0L, "AE",           "AE",    "AESTDTC",       2, "Cough",  "TTAE1",
+    "02",     ymd("2021-02-03"),    1L, "END OF STUDY", "ADSL",  "EOSDT",        NA, "Cough",  "TTAE1"
   ) %>%
     # nolint end
     mutate(
@@ -308,18 +305,18 @@ test_that("derive_param_tte Test 4: by_vars parameter works correctly", {
 
 ## Test 5: an error is issued if some of the by variables are missing ----
 test_that("derive_param_tte Test 5: an error is issued if some of the by variables are missing", {
-  adsl <- tribble(
+  adsl <- tibble::tribble(
     ~USUBJID, ~TRTSDT,           ~EOSDT,
     "01",     ymd("2020-12-06"), ymd("2021-03-06"),
     "02",     ymd("2021-01-16"), ymd("2021-02-03")
   ) %>%
     mutate(STUDYID = "AB42")
 
-  ae <- tribble(
+  ae <- tibble::tribble(
     ~USUBJID, ~AESTDTC,     ~AESEQ, ~AEDECOD,
-    "01",     "2021-01-03", 1,      "Flu",
-    "01",     "2021-03-04", 2,      "Cough",
-    "01",     "2021-01-01", 3,      "Flu"
+    "01",     "2021-01-03",      1, "Flu",
+    "01",     "2021-03-04",      2, "Cough",
+    "01",     "2021-01-01",      3, "Flu"
   ) %>%
     mutate(
       STUDYID = "AB42",
@@ -369,7 +366,7 @@ test_that("derive_param_tte Test 5: an error is issued if some of the by variabl
 
 ## Test 6: errors if all by vars are missing in all source datasets ----
 test_that("derive_param_tte Test 6: errors if all by vars are missing in all source datasets", {
-  adsl <- tribble(
+  adsl <- tibble::tribble(
     ~USUBJID, ~TRTSDT,           ~EOSDT,
     "01",     ymd("2020-12-06"), ymd("2021-03-06"),
     "02",     ymd("2021-01-16"), ymd("2021-02-03")
@@ -378,9 +375,9 @@ test_that("derive_param_tte Test 6: errors if all by vars are missing in all sou
 
   ae <- tibble::tribble(
     ~USUBJID, ~AESTDTC,     ~AESEQ, ~AEDECOD,
-    "01",     "2021-01-03", 1,      "Flu",
-    "01",     "2021-03-04", 2,      "Cough",
-    "01",     "2021-01-01", 3,      "Flu"
+    "01",     "2021-01-03",      1, "Flu",
+    "01",     "2021-03-04",      2, "Cough",
+    "01",     "2021-01-01",      3, "Flu"
   ) %>%
     mutate(
       STUDYID = "AB42",
@@ -431,18 +428,18 @@ test_that("derive_param_tte Test 6: errors if all by vars are missing in all sou
 
 ## Test 7: errors if PARAMCD and by_vars are not one to one ----
 test_that("derive_param_tte Test 7: errors if PARAMCD and by_vars are not one to one", {
-  adsl <- tribble(
+  adsl <- tibble::tribble(
     ~USUBJID, ~TRTSDT,           ~EOSDT,
     "01",     ymd("2020-12-06"), ymd("2021-03-06"),
     "02",     ymd("2021-01-16"), ymd("2021-02-03")
   ) %>%
     mutate(STUDYID = "AB42")
 
-  ae <- tribble(
+  ae <- tibble::tribble(
     ~USUBJID, ~AESTDTC,     ~AESEQ, ~AEDECOD,
-    "01",     "2021-01-03", 1,      "Flu",
-    "01",     "2021-03-04", 2,      "Cough",
-    "01",     "2021-01-01", 3,      "Flu"
+    "01",     "2021-01-03",      1, "Flu",
+    "01",     "2021-03-04",      2, "Cough",
+    "01",     "2021-01-01",      3, "Flu"
   ) %>%
     mutate(
       STUDYID = "AB42",
@@ -494,18 +491,18 @@ test_that("derive_param_tte Test 7: errors if PARAMCD and by_vars are not one to
 
 ## Test 8: errors if set_values_to contains invalid expressions ----
 test_that("derive_param_tte Test 8: errors if set_values_to contains invalid expressions", {
-  adsl <- tribble(
+  adsl <- tibble::tribble(
     ~USUBJID, ~TRTSDT,           ~EOSDT,
     "01",     ymd("2020-12-06"), ymd("2021-03-06"),
     "02",     ymd("2021-01-16"), ymd("2021-02-03")
   ) %>%
     mutate(STUDYID = "AB42")
 
-  ae <- tribble(
+  ae <- tibble::tribble(
     ~USUBJID, ~AESTDTC,     ~AESEQ, ~AEDECOD,
-    "01",     "2021-01-03", 1,      "Flu",
-    "01",     "2021-03-04", 2,      "Cough",
-    "01",     "2021-01-01", 3,      "Flu"
+    "01",     "2021-01-03",      1, "Flu",
+    "01",     "2021-03-04",      2, "Cough",
+    "01",     "2021-01-01",      3, "Flu"
   ) %>%
     mutate(
       STUDYID = "AB42",
@@ -565,18 +562,18 @@ test_that("derive_param_tte Test 8: errors if set_values_to contains invalid exp
 
 ## Test 9: error is issued if parameter code already exists ----
 test_that("derive_param_tte Test 9: error is issued if parameter code already exists", {
-  adsl <- tribble(
+  adsl <- tibble::tribble(
     ~USUBJID, ~TRTSDT,           ~EOSDT,
     "01",     ymd("2020-12-06"), ymd("2021-03-06"),
     "02",     ymd("2021-01-16"), ymd("2021-02-03")
   ) %>%
     mutate(STUDYID = "AB42")
 
-  ae <- tribble(
+  ae <- tibble::tribble(
     ~USUBJID, ~AESTDTC,     ~AESEQ, ~AEDECOD,
-    "01",     "2021-01-03", 1,      "Flu",
-    "01",     "2021-03-04", 2,      "Cough",
-    "01",     "2021-01-01", 3,      "Flu"
+    "01",     "2021-01-03",      1, "Flu",
+    "01",     "2021-03-04",      2, "Cough",
+    "01",     "2021-01-01",      3, "Flu"
   ) %>%
     mutate(
       STUDYID = "AB42",
@@ -607,8 +604,8 @@ test_that("derive_param_tte Test 9: error is issued if parameter code already ex
 
   expected_output <- tibble::tribble(
     ~USUBJID, ~ADT,              ~CNSR, ~EVENTDESC,     ~SRCDOM, ~SRCVAR,   ~SRCSEQ,
-    "01",     ymd("2021-01-01"), 0L,    "AE",           "AE",    "AESTDTC", 3,
-    "02",     ymd("2021-02-03"), 1L,    "END OF STUDY", "ADSL",  "EOSDT",   NA
+    "01",     ymd("2021-01-01"),    0L, "AE",           "AE",    "AESTDTC",       3,
+    "02",     ymd("2021-02-03"),    1L, "END OF STUDY", "ADSL",  "EOSDT",        NA
   ) %>%
     mutate(
       STUDYID = "AB42",
@@ -634,30 +631,108 @@ test_that("derive_param_tte Test 9: error is issued if parameter code already ex
   )
 })
 
-# print.tte_source ----
-## Test 10: tte_source` objects are printed as intended ----
-test_that("`print.tte_source Test 10: tte_source` objects are printed as intended", {
-  ttae <- event_source(
-    dataset_name = "ae",
-    date = AESTDTC,
+## Test 10: ensuring ADT is not NA because of missing start_date ----
+test_that("derive_param_tte Test 10: ensuring ADT is not NA because of missing start_date", {
+  adsl <- tibble::tribble(
+    ~USUBJID, ~TRTSDT,                ~LSTALVDT,
+    "01",     NA,                     ymd("2022-08-10"),
+    "02",     NA,                     ymd("2022-09-12"),
+    "03",     ymd("2020-10-13"),      ymd("2022-07-21")
+  ) %>%
+    mutate(STUDYID = "AB42")
+
+  ae <- tibble::tribble(
+    ~USUBJID,  ~AESEQ, ~ASTDT,
+    "01",           1, ymd("2020-08-10"),
+    "02",           2, ymd("2020-08-15"),
+    "03",           3, ymd("2020-12-10"),
+  ) %>%
+    mutate(STUDYID = "AB42")
+
+  eos <- censor_source(
+    "adsl",
+    date = LSTALVDT,
     set_values_to = vars(
-      EVENTDESC = "AE",
-      SRCDOM = "AE",
-      SRCVAR = "AESTDTC",
+      EVNTDESC = "Last Known Alive Date",
+      SRCDOM = "ADSL",
+      SRCVAR = "LSTALVDT"
+    )
+  )
+
+  ttae <- event_source(
+    dataset_name = "adae",
+    date = ASTDT,
+    set_values_to = vars(
+      EVNTDESC = "Any Adverse Event",
+      SRCDOM = "ADAE",
+      SRCVAR = "AEDECOD",
       SRCSEQ = AESEQ
     )
   )
-  expected_print_output <- c(
-    "<tte_source> object",
-    "dataset_name: \"ae\"",
-    "filter: NULL",
-    "date: AESTDTC",
-    "censor: 0",
-    "set_values_to:",
-    "  EVENTDESC: \"AE\"",
-    "  SRCDOM: \"AE\"",
-    "  SRCVAR: \"AESTDTC\"",
-    "  SRCSEQ: AESEQ"
+
+  actual_output <- derive_param_tte(
+    dataset_adsl = adsl,
+    source_datasets = list(adae = ae, adsl = adsl),
+    start_date = TRTSDT,
+    event_conditions = list(ttae),
+    censor_conditions = list(eos),
+    set_values_to = vars(
+      PARAMCD = "ANYAETTE",
+      PARAM = "Time to any first adverse event"
+    )
+  )
+
+  expected_output <- tibble::tribble(
+    ~USUBJID, ~EVNTDESC,           ~SRCDOM, ~SRCVAR,  ~SRCSEQ, ~CNSR, ~ADT,              ~STARTDT,
+    "01",     "Any Adverse Event", "ADAE",  "AEDECOD",      1,    0L, ymd("2020-08-10"), NA,
+    "02",     "Any Adverse Event", "ADAE",  "AEDECOD",      2,    0L, ymd("2020-08-15"), NA,
+    "03",     "Any Adverse Event", "ADAE",  "AEDECOD",      3,    0L, ymd("2020-12-10"), ymd("2020-10-13") # nolint
+  ) %>%
+    mutate(
+      STUDYID = "AB42",
+      PARAMCD = "ANYAETTE",
+      PARAM = "Time to any first adverse event"
+    )
+
+  expect_dfs_equal(
+    actual_output,
+    expected_output,
+    keys = c("USUBJID", "PARAMCD")
   )
-  expect_identical(capture.output(print(ttae)), expected_print_output)
+})
+
+## Test 11: error is issued if package does not exist ----
+test_that("list_tte_source_objects Test 10: error is issued if package does not exist", {
+  expect_error(
+    list_tte_source_objects(package = "tte"),
+    regexp = "No package called 'tte' is installed and hence no `tte_source` objects are available"
+  )
+})
+
+## Test 12: calling list_tte_source_objects results in expected output objects ----
+test_that("list_tte_source_objects Test 11: expected objects produced", {
+  expected_output <- tibble::tribble(
+    ~object, ~dataset_name, ~filter, ~date, ~censor,
+    "ae_ser_event", "adae", quote(TRTEMFL == "Y" & AESER == "Y"), "ASTDT", 0,
+    "ae_gr2_event", "adae", quote(TRTEMFL == "Y" & ATOXGR == "2"), "ASTDT", 0,
+    "ae_sev_event", "adae", quote(TRTEMFL == "Y" & AESEV == "SEVERE"), "ASTDT", 0,
+    "ae_gr4_event", "adae", quote(TRTEMFL == "Y" & ATOXGR == "4"), "ASTDT", 0,
+    "ae_gr3_event", "adae", quote(TRTEMFL == "Y" & ATOXGR == "3"), "ASTDT", 0,
+    "lastalive_censor", "adsl", NULL, "LSTALVDT", 1,
+    "ae_event", "adae", quote(TRTEMFL == "Y"), "ASTDT", 0,
+    "death_event", "adsl", quote(DTHFL == "Y"), "DTHDT", 0,
+    "ae_gr35_event", "adae", quote(TRTEMFL == "Y" & ATOXGR %in% c("3", "4", "5")), "ASTDT", 0,
+    "ae_wd_event", "adae", quote(TRTEMFL == "Y" & AEACN == "DRUG WITHDRAWN"), "ASTDT", 0,
+    "ae_gr1_event", "adae", quote(TRTEMFL == "Y" & ATOXGR == "1"), "ASTDT", 0,
+    "ae_gr5_event", "adae", quote(TRTEMFL == "Y" & ATOXGR == "5"), "ASTDT", 0,
+  ) %>%
+    mutate(
+      filter = as.character(filter),
+      censor = as.integer(censor)
+    )
+
+  observed_output <- list_tte_source_objects(package = "admiral") %>%
+    select(object, dataset_name, filter, date, censor)
+
+  expect_dfs_equal(expected_output, observed_output, keys = c("object"))
 })
